#ifndef _PyMOL_VERSION
#define _PyMOL_VERSION "1.7.0.0"
#endif

#ifndef _PYMOL_1_x
#define _PYMOL_1_x
#endif

#ifndef _PyMOL_VERSION_double
#define _PyMOL_VERSION_double 1.700
#endif


/* for session file compatibility */

#ifndef _PyMOL_VERSION_int
#define _PyMOL_VERSION_int 1700
#endif
